@@ -1,9 +1,9 @@
 package Exception::DB;
-$Exception::DB::VERSION = '0.012';
+$Exception::DB::VERSION = '0.013';
 use base qw(Exception);
 
 package Exception::DB::DuplicateEntry;
-$Exception::DB::DuplicateEntry::VERSION = '0.012';
+$Exception::DB::DuplicateEntry::VERSION = '0.013';
 use base qw(Exception::DB);
 
 =head1 Name
@@ -35,7 +35,7 @@ apt-get install libqbit-application-model-db-perl (http://perlhub.ru/)
 =cut
 
 package QBit::Application::Model::DB;
-$QBit::Application::Model::DB::VERSION = '0.012';
+$QBit::Application::Model::DB::VERSION = '0.013';
 use qbit;
 
 use base qw(QBit::Application::Model);
@@ -353,8 +353,6 @@ B<Example:>
 sub begin {
     my ($self) = @_;
 
-    $self->_connect();
-
     $self->{'__SAVEPOINTS__'} == 0
       ? $self->_do('BEGIN')
       : $self->_do('SAVEPOINT SP' . $self->{'__SAVEPOINTS__'});
@@ -377,8 +375,6 @@ B<Example:>
 sub commit {
     my ($self) = @_;
 
-    $self->_connect();
-
     --$self->{'__SAVEPOINTS__'}
       ? $self->_do('RELEASE SAVEPOINT SP' . $self->{'__SAVEPOINTS__'})
       : $self->_do('COMMIT');
@@ -399,8 +395,6 @@ B<Example:>
 sub rollback {
     my ($self) = @_;
 
-    $self->_connect();
-
     my $sql =
       --$self->{'__SAVEPOINTS__'}
       ? $self->_do('ROLLBACK TO SAVEPOINT SP' . $self->{'__SAVEPOINTS__'})
@@ -674,7 +668,7 @@ sub _sub_with_connected_dbh {
     my @res;
 
     try {
-        $self->_connect();
+        $self->_connect() unless $self->{'__SAVEPOINTS__'};
         @res = $sub->(@{$params || []});
     }
     catch {
